@@ -6,14 +6,8 @@
 
 #include <QObject>
 
-#include <akonadi-calendar_version.h>
-#if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
 #include <Akonadi/ETMCalendar>
 #include <Akonadi/IncidenceChanger>
-#else
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
-#endif
 
 #include <Akonadi/CollectionFilterProxyModel>
 #include <KConfigWatcher>
